summaryrefslogtreecommitdiffstats
path: root/src/import/chips/p9/procedures/hwp/perv/p9_mem_startclocks.H
diff options
context:
space:
mode:
Diffstat (limited to 'src/import/chips/p9/procedures/hwp/perv/p9_mem_startclocks.H')
-rw-r--r--src/import/chips/p9/procedures/hwp/perv/p9_mem_startclocks.H25
1 files changed, 17 insertions, 8 deletions
diff --git a/src/import/chips/p9/procedures/hwp/perv/p9_mem_startclocks.H b/src/import/chips/p9/procedures/hwp/perv/p9_mem_startclocks.H
index 30361843b..f41132e5e 100644
--- a/src/import/chips/p9/procedures/hwp/perv/p9_mem_startclocks.H
+++ b/src/import/chips/p9/procedures/hwp/perv/p9_mem_startclocks.H
@@ -7,7 +7,7 @@
/* */
/* EKB Project */
/* */
-/* COPYRIGHT 2015 */
+/* COPYRIGHT 2015,2016 */
/* [+] International Business Machines Corp. */
/* */
/* */
@@ -21,11 +21,11 @@
///
/// @brief Start clocks on MBA/MCAs
//------------------------------------------------------------------------------
-// *HWP HW Owner : Anusha Reddy Rangareddygari <anusrang@in.ibm.com>
+// *HWP HW Owner : Abhishek Agarwal <abagarw8@in.ibm.com>
// *HWP HW Backup Owner : Srinivas V Naga <srinivan@in.ibm.com>
-// *HWP FW Owner : Sunil Kumar <skumar8j@in.ibm.com>
+// *HWP FW Owner : Sunil kumar <skumar8j@in.ibm.com>
// *HWP Team : Perv
-// *HWP Level : 1
+// *HWP Level : 2
// *HWP Consumed by : HB
//------------------------------------------------------------------------------
@@ -37,15 +37,24 @@
#include <fapi2.H>
-typedef fapi2::ReturnCode (*p9_mem_startclocks_FP_t)(const fapi2::Target<fapi2::TARGET_TYPE_PROC_CHIP>&);
+typedef fapi2::ReturnCode (*p9_mem_startclocks_FP_t)(
+ const fapi2::Target<fapi2::TARGET_TYPE_PROC_CHIP>&);
-/// @brief Drop fences and tholds on MBA/MCAs
+/// @brief --drop vital fence
+/// --reset abstclk muxsel and syncclk muxsel
+/// --Module align chiplets
+/// --Module clock start stop
+/// --Check clock stat SL, NSL , ARY
+/// --drop chiplet fence
+/// --check checkstop register
+/// --clear flush inhibit to go into flush mode
///
/// @param[in] i_target_chiplet Reference to TARGET_TYPE_PROC_CHIP target
/// @return FAPI2_RC_SUCCESS if success, else error code.
extern "C"
{
- fapi2::ReturnCode p9_mem_startclocks(const fapi2::Target<fapi2::TARGET_TYPE_PROC_CHIP>& i_target_chiplet);
+ fapi2::ReturnCode p9_mem_startclocks(const
+ fapi2::Target<fapi2::TARGET_TYPE_PROC_CHIP>& i_target_chip);
}
#endif
OpenPOWER on IntegriCloud
@@ -37,15 +37,24 @@
///
-/// @param[in] i_target_chiplet Reference to TARGET_TYPE_PROC_CHIP target
+/// @param[in] i_target_chip Reference to TARGET_TYPE_PROC_CHIP target
/// @return FAPI2_RC_SUCCESS if success, else error code.
extern "C"